# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.4.0~aa087a1',
    built_at='2024-03-05 07:56:10Z',
    sha='aa087a1204153b77f1cc5e579d711addb4e1c45b',
    branch='HEAD',
    tag='v4.4.0',
)
